%global commit 3fb18995933a9c992a962e99d87037821e9a3ed4
%global shortcommit %(c=%{commit}; echo ${c:0:7})

%global hadoop_version 23
%global hbase_version 95
%global javacc_version SYSTEM
%global jetty_version 8.1.14.v20131031
%global jline_version 1
%global netty_version 3

Name:          pig
Version:       0.13.0
Release:       1%{?dist}
Summary:       Apache Pig

License:       ASL 2.0
URL:           http://pig.apache.org/
Source0:       https://github.com/apache/%{name}/archive/%{commit}/%{name}-%{commit}.tar.gz
Source1:       pig-env.sh

BuildRequires: apache-ivy >= 2.3.0
BuildRequires: automaton
BuildRequires: ant-contrib
BuildRequires: avro-mapred
BuildRequires: avro-trevni
BuildRequires: hadoop-tests
BuildRequires: hbase
BuildRequires: high-scale-lib
BuildRequires: htrace
BuildRequires: ivy-local >= 3.5.0-2
BuildRequires: javacc
BuildRequires: java-devel
BuildRequires: jdiff
BuildRequires: jetty8
BuildRequires: jline1
BuildRequires: json_simple
BuildRequires: jython >= 2.5.3
BuildRequires: maven-local >= 3.5.0-2
BuildRequires: metrics
BuildRequires: netty3
BuildRequires: xmvn >= 1.5.0

BuildArch:     noarch
ExcludeArch:   %{arm}

Requires: avro-mapred
Requires: avro-trevni
Requires: hadoop-tests
Requires: hbase
Requires: htrace
Requires: jetty8
Requires: json_simple

%description
Apache Pig is a platform for analyzing large data sets that 
consists of a high-level language for expressing data analysis 
programs, coupled with infrastructure for evaluating these 
programs. The salient property of Pig programs is that their 
structure is amenable to substantial parallelization, 
which in turns enables them to handle very large data sets. 

%package javadoc
Summary:       Javadoc for %{name}

%description javadoc
This package contains javadoc for %{name}.

%prep
%setup -q -n  %{name}-%{commit}
find -name '*.jar' -delete

sed -i 's/\r//' LICENSE.txt NOTICE.txt README.txt

# ivy dep changes
sed -i 's/groovy-all/groovy/' ivy.xml
sed -i '/jruby-complete/a <dependency org="org.jruby.extras" name="bytelist" rev="${jruby.version}" conf="compile->master"/>' ivy.xml
sed -i 's/jruby-complete/jruby/' ivy.xml

sed -i 's/org="hsqldb"/org="org.hsqldb"/' ivy.xml
sed -i '/parquet-pig-bundle/d' ivy.xml

# crude multi-line deletions
sed -i '/jersey-bundle/,+1d' ivy.xml
sed -i '/org.mortbay.jetty/,+1d' ivy.xml
sed -i '/accumulo-core/,+14d' ivy.xml
sed -i '/accumulo-minicluster/,+14d' ivy.xml
sed -i '/org.vafer/,+2d' ivy.xml

# remove/fix test deps
sed -i '/avro-tools/,+1d' ivy.xml
sed -i '/jopt-simple/,+1d' ivy.xml
sed -i '/hive-exec/,+1d' ivy.xml
sed -i 's/com.yammer.metrics/com.codahale.metrics/' ivy.xml

#TODO: problems with this one but appears to be unneeded
sed -i '/hadoop-yarn-server-tests/,+3d' ivy.xml

# harmless missing ant exec but we'll take it out
sed -i "/<svnversion/d" build.xml

# remove parquet src files
#TODO: revisit if parquet comes in
rm src/org/apache/pig/builtin/ParquetLoader.java
rm src/org/apache/pig/builtin/ParquetStorer.java

# remove accumulo src files
#TODO: revisit if accumulo comes in
rm src/org/apache/pig/backend/hadoop/accumulo/*.java

# change jython imports to their guava equivalents
sed -i "/org.python.google.common.collect.Maps/d" src/org/apache/pig/builtin/InvokerGenerator.java
sed -i "s/org.python.google/com.google/" src/org/apache/pig/newplan/logical/expression/UserFuncExpression.java
sed -i "s/org.python.google/com.google/" src/org/apache/pig/tools/grunt/GruntParser.java

# update to jetty 8
sed -i "s/org.mortbay/org.eclipse.jetty.util/" src/org/apache/pig/data/SchemaTuple.java
sed -i "s/Log.warn/Log.getLog().warn/" src/org/apache/pig/data/SchemaTuple.java
sed -i "s/org.mortbay/org.eclipse.jetty.util/" src/org/apache/pig/impl/util/avro/AvroStorageSchemaConversionUtilities.java
sed -i "s/Log.warn/Log.getLog().warn/" src/org/apache/pig/impl/util/avro/AvroStorageSchemaConversionUtilities.java

# netty version hardcoded in a test config for some reason
sed -i 's/3.2.2.Final/%{netty_version}/' ivy.xml

# fix generics for returned Lists
sed -i "s/tree.getChildren()/(List<Tree>)tree.getChildren()/" src/org/apache/pig/parser/QueryParser.g
sed -i "s/((CommonTree)parserTree).getChildren())/(List<Tree>)((CommonTree)parserTree).getChildren())/" src/org/apache/pig/parser/DryRunGruntParser.java

%build

ant -Doffline=true -Divy.mode=local -Divysettings.xml=/etc/ivy/ivysettings.xml \
      -Dpig.version=%{version} -Dpig.version.suffix= \
      -Dhadoopversion=%{hadoop_version} -Dhbaseversion=%{hbase_version} \
      -Djavacc.version=%{javacc_version} -Djline.version=%{jline_version} \
      -Djetty.version=%{jetty_version} -Dnetty.version=%{netty_version} \
      jar-withouthadoop javadoc
      
# tests not run due to missing avro-tool dep

%install

# create the root from here
install -d -m 0755 %{buildroot}%{_datadir}/%{name}
install -d -m 0755 %{buildroot}%{_datadir}/%{name}/bin
install -d -m 0755 %{buildroot}%{_datadir}/%{name}/lib

# bin
install -dm 755 %{buildroot}%{_bindir}
cp -p bin/%{name} %{buildroot}%{_datadir}/%{name}/bin
ln -s %{_datadir}/%{name}/bin/%{name} %{buildroot}%{_bindir}/%{name}

# conf
mkdir -p %{buildroot}%{_sysconfdir}/%{name}
cp -p conf/log4j.properties.template %{buildroot}%{_sysconfdir}/%{name}/log4j.properties
cp -p conf/pig.properties %{buildroot}%{_sysconfdir}/%{name}
cp %{SOURCE1} %{buildroot}%{_sysconfdir}/%{name}

# jar
install -d -m 0755 %{buildroot}%{_javadir}/%{name}
install -d -m 0755 %{buildroot}%{_mavenpomdir}
install -m 0644 build/%{name}-%{version}-withouthadoop.jar %{buildroot}%{_javadir}/%{name}.jar
ln -s %{_javadir}/%{name}.jar %{buildroot}%{_datadir}/%{name}/%{name}-withouthadoop.jar
%add_maven_depmap org.apache.pig:pig:%{version} %{name}.jar

# lib
cp build/ivy/lib/Pig/*.jar %{buildroot}%{_datadir}/%{name}/lib
# throw away a few test compilation deps which we likely don't need
# we're probably still covered by the mondo hadoop classpath
for j in high-scale-lib hsqldb junit metrics-core netty protobuf-java xalan xercesImpl; do
    rm %{buildroot}%{_datadir}/%{name}/lib/$j*.jar
done
%{_bindir}/xmvn-subst %{buildroot}%{_datadir}/%{name}/lib

# javadocs
mkdir -p %{buildroot}%{_javadocdir}
cp -r build/docs %{buildroot}%{_javadocdir}/%{name}

%files -f .mfiles
%doc LICENSE.txt NOTICE.txt README.txt
%config(noreplace) %{_sysconfdir}/%{name}
%{_bindir}/%{name}
%{_datadir}/%{name}

%files javadoc
%doc LICENSE.txt NOTICE.txt
%{_javadocdir}/%{name}

%changelog
* Mon Jul 07 2014 Peter MacKinnon <pmackinn@redhat.com> 0.13.0-1
- update to 0.13.0
- remove hadoop-yarn-server-tests dep

* Fri Jun 20 2014 Peter MacKinnon <pmackinn@redhat.com> 0.12.0-5
- enable jython support
- add jline1 BR
- fix some List generics from antlr update

* Sat Jun 07 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.12.0-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Fri Mar 28 2014 Michael Simacek <msimacek@redhat.com> - 0.12.0-3
- Use Requires: java-headless rebuild (#1067528)

* Fri Feb 14 2014 Peter MacKinnon <pmackinn@redhat.com> 0.12.0-2
- Add in bin and env script
- Rework layout

* Mon Jan 13 2014 Peter MacKinnon <pmackinn@redhat.com> 0.12.0-1
- Initial rpm
